#
# A re-implementation of https://github.com/jbloom/PRJNA692319_public
#

# Reference genome SARS-COV-2 Refseq genome
ACC = NC_045512

# The downloaded alignment file.
BAM = bam/sars2.bam

# Download data from NCBI via Entrez API
include src/ncbi.mk

# Call variants via bcftools.
include src/freebayes.mk

# Filter variants with bcftools.
include src/filter.mk

${BAM}: ${REF}
	mkdir -p bam cons
	curl http://data.biostarhandbook.com/bam/sars2.bam > ${BAM}
	curl http://data.biostarhandbook.com/fasta/EPI_ISL_434692.fa > cons/EPI_ISL_434692.fa
	samtools index ${BAM}

# Generate consensus sequence from the filtered VCF
cons/bcf.fa: ${OUT}
	mkdir -p cons
	bcftools consensus -f ${REF} vcf/filtered.vcf.gz -p bcf_cons_ | bio fasta --trim A > cons/bcf.fa

# Generate textual variants from the VCF.
cons/bcf.tsv: ${OUT}
	cat vcf/filtered.vcf.gz | bcftools query -f '%CHROM\t%POS\t%REF\t%ALT\t%DP\t%SRF\t%SRR\t%SAF\t%SAR\n' > cons/bcf.tsv

# Generate consensus sequence with ivar.
cons/ivar.fa: ${OUT}
	samtools mpileup -aa -A -d 0 -Q 20 bam/sars2.bam | ivar consensus -m 1 -t 0.5 -p cons/ivar.fa

# Generate variants with ivar.
cons/ivar.tsv: ${OUT}
	samtools mpileup -aa -A -d 0 -Q 20 bam/sars2.bam | ivar variants -r ${REF} -g ${GFF} -t 0.5 -p cons/ivar

# Get the the comparison sequences
cons/wuhan.fa:
	bio fetch NC_045512 | bio fasta --rename Wuhan-Hu-1 --trim A > cons/wuhan.fa
	bio fetch MN996532 | bio fasta --rename RaTG13 --trim A > cons/ratg13.fa
	bio fetch MZ937000 | bio fasta --rename BANAL25 --trim A > cons/banal25.fa

# Shortcut to generating all consensus sequences.
consensus: cons/bcf.fa cons/bcf.tsv cons/ivar.fa cons/ivar.tsv cons/wuhan.fa
	@cat cons/wuhan.fa cons/ratg13.fa  cons/banal25.fa | mafft --quiet - | bio format --table | column -t
	@echo ""
	@cat cons/bcf.fa  cons/ratg13.fa  cons/banal25.fa | mafft --quiet - | bio format --table | column -t

check:


# Remove computed files
clean:
	rm -rf ${BAM} cons
