
# De default SRR run
SRR ?=SRR1553591

# The reference genome.
ACC ?= AF086833

# How many samples to process.
NUM ?= 20

# How many reads to obtain per sample.
N ?= 100000

# Load the aligner module.
include flow/aligner.mk

# The metadata as a text file.
runinfo.tsv:
	bio search PRJNA257197 --tab > runinfo.tsv

# The metadata as a JSON object.
runinfo.json:
	bio search PRJNA257197 --all > runinfo.json

# The file that lists the samples we want to process.
ids.txt: runinfo.tsv runinfo.json
	cat runinfo.tsv | cut -f 1 | head -${NUM} > ids.txt

# Generates VCF file names based on ids.txt.
vcf.txt: ids.txt
	cat ids.txt | parallel echo vcf/{}.vcf.gz > vcf.txt

# Merge the VCF files into a single VCF file.
merged.vcf: vcf.txt
	cat vcf.txt | parallel --xargs bcftools merge  {} > merged.vcf

# Extract the variable sequences, align these then draw a tree
ebola.tree: merged.vcf runinfo.json
	python -m biorun.vcf2fasta merged.vcf --json runinfo.json > input.fa
	mafft input.fa > aligned.fa
	fasttree -nt aligned.fa > ebola.tree
