#
# Generates SNP calls with bcftools.
#

# Input BAM file.
BAM ?= bam/alignment.bam

# Reference genome.
REF ?= refs/genome.fa

# Additional bcf flags options
BCF_FLAGS = --ploidy 2

# Name of the VCF with all variants.
VCF ?= vcf/variants.vcf.gz

# Targets that are not files.
.PHONY: vcf vcf! install help

# The first target is always the help.
usage::
	@echo ""
	@echo "# src/bcftools.mk # calls variants using bcftools"
	@echo ""
	@echo "  make vcf"
	@echo ""
	@echo "  in:  REF=${REF}"
	@echo "  in:  BAM=${BAM}"
	@echo ""
	@echo "  out: VCF=${VCF}"
	@echo ""
	@echo "  cmd: ${CMD_BCF}"
	@echo ""

# The command that will be executed
CMD_BCF ?= bcftools mpileup -O v -f ${REF} ${BAM} | bcftools call ${BCF_FLAGS} -mv -O u | bcftools norm -f ${REF} -d all -O u | bcftools filter -e '${EXC}' -O z

${VCF}: ${BAM} ${REF}
	@mkdir -p $(dir $@)
	bcftools mpileup -O v -f ${REF} ${BAM} | bcftools call ${BCF_FLAGS} -mv -O u | bcftools norm -f ${REF} -d all -O z > ${VCF}
	bcftools index -f $@

vcf: ${VCF}
	@echo "# VCF=${VCF} (`bcftools view ${VCF} |  grep -v '^#' | wc -l | tr -d ' '` variants)"

vcf!:
	@rm -rf ${VCF}

install::
	@echo mamba install bcftools
