#
# Download data via HTTP or RSYNC protocols.
#

FASTA ?= rsync://hgdownload.soe.ucsc.edu/goldenPath/hg38/chromosomes/chr22.fa.gz

# The reference genome path.
DIR ?= refs

# The reference genome path.
OUT ?= ${DIR}/$(notdir ${URL})

# General usage information.
usage::
	@echo ""
	@echo "# download.mk: downloads data via HTTP or rsync protocols."
	@echo ""
	@echo "  make get    # HTTP download"
	@echo "  make rsync  # Rsync download"
	@echo ""
	@echo "  in:  DIR=${DIR}"
	@echo "  in:  URL=${URL}"
	@echo "  out: OUT=${OUT}"
	@echo ""
	@echo "  cmd: ${GET_CMD}"
	@echo ""
	@echo "  cmd: ${RSYNC_CMD}"
	@echo ""

# Download via HTTP.
GET_CMD = curl ${URL} >  ${OUT}

# Download via rsync.
RSYNC_CMD = rsync -avz -P ${URL} ${OUT}

# Download the file.
${OUT}:
	mkdir -p ${DIR}
	${GET_CMD}

# Show the downloaded file stats.
get:: ${OUT}
	@ls -lh ${OUT}

get!::
	@rm -rf ${OUT}

rsync::
	mkdir -p ${DIR}
	${RSYNC_CMD}

rsync!::
	@echo "# rsync operations cannot be cleaned up"

# Installation instructions
install::
	@echo "# no installation required"
