#
# Generates SNP calls with bcftools.
#

# Input BAM file.
BAM ?= bam/aligned.bam

# Reference genome.
REF ?= refs/genome.fa

# Name of the VCF with all variants.
VCF ?= vcf/variants.vcf.gz

# The name of the filtered variants.
OUT ?= vcf/filtered.vcf.gz

# VCF exclusion condition.
FLT ?= -e 'QUAL<30'

# Targets that are not files.
.PHONY: filter filter! install usage


# The filtering command
FILTER_CMD =cat ${VCF} | bcftools view ${FLT} -O z > ${OUT}

# The first target is always the help.
usage::
	@echo ""
	@echo "# src/filter.mk # filters variants using bcftools"
	@echo ""
	@echo "  make filter"
	@echo ""
	@echo "  in:  VCF=${VCF}"
	@echo "  in:  FLT=${FLT}"
	@echo ""
	@echo "  out: OUT=${OUT}"
	@echo ""
	@echo "  cmd: ${FILTER_CMD}"
	@echo ""

${OUT}: ${VCF}
	@mkdir -p $(dir $@)
	${FILTER_CMD}
	bcftools index ${OUT}

filter: ${OUT}
	@echo "# VCF=${VCF} (`bcftools view ${VCF} |  grep -v '^#' | wc -l | tr -d ' '` variants)"
	@echo "# OUT=${OUT} (`bcftools view ${OUT} |  grep -v '^#' | wc -l | tr -d ' '` filtered variants)"

filter!:
	@rm -f ${OUT}

install::
	@echo mamba install bcftools
