#
# Generates SNP calls with freebaye
#

# Input BAM file.
BAM ?= bam/alignment.bam

# Reference genome.
REF ?= refs/genome.fa

# Name of the VCF with all variants.
VCF ?= vcf/variants.vcf.gz

# Targets that are not files.
.PHONY: vcf vcf! install help

# Additional freebayes options
FRB_FLAGS = --pvar 0.5

# The main command.
FRB_CMD = freebayes ${FRB_FLAGS} -f ${REF} ${BAM} | bcftools norm -f ${REF} -d all -O z  > ${VCF}

# The first target is always the usage.
usage::
	@echo ""
	@echo "# src/freebayes.mk: calls variants using freebayes"
	@echo ""
	@echo "  make vcf"
	@echo ""
	@echo "  in:  REF=${REF}"
	@echo "  in:  BAM=${BAM}"
	@echo "  out: VCF=${VCF}"
	@echo ""
	@echo "  cmd: ${FRB_CMD}"
	@echo ""


${VCF}: ${BAM} ${REF}
	@mkdir -p $(dir $@)
	${FRB_CMD}
	bcftools index -f $@

vcf: ${VCF}
	@echo ""
	@echo "# VCF=${VCF} (`bcftools view ${VCF} |  grep -v '^#' | wc -l | tr -d ' '` variants)"
	@echo ""

vcf!:
	@rm -rf ${VCF}

# Installation instructions.
install::
	@echo mamba install bcftools freebayes
