
#
# Runs the ivar package.
#

# Input BAM file.
BAM ?= bam/alignment.bam

# Reference genome.
REF ?= refs/genome.fa

# The GFF annotation file.
GFF = refs/genome.gff

# The prefix for the output files.
PREFIX = ivar/consensus

# The ivar consensus file.
CONS = ${PREFIX}.fa

# The ivar variants file.
VARS = ${PREFIX}.tsv

# Targets that are not files.
.PHONY: cons cons! vars vars! install help

usage::
	@echo "# src/ivar.mk: runs the ivar suite"
	@echo ""
	@echo "  make cons vars"
	@echo ""
	@echo "  in: REF=${REF}"
	@echo "  in: REF=${REF}"
	@echo "  in: BAM=${BAM}"
	@echo "  in: PREFIX=${PREFIX}"
	@echo ""
	@echo "  out: CONS=${CONS}"
	@echo "  out: VARS=${VARS}"
	@echo ""
	@echo "  cmd: ${CONS_CMD}"
	@echo "  cmd: ${VARS_CMD}"
	@echo ""

# The commands
CONS_CMD = samtools mpileup ${BAM} -aa -A -d 0 -Q 20 | ivar consensus -p ${PREFIX} -t 0.5 -m 1
VARS_CMD = samtools mpileup ${BAM} -aa -A -d 0 -Q 20 | ivar variants -p ${PREFIX} -t 0.5 -m 1

# Generates the ivar consensus sequences.
${CONS}: ${BAM}
	@mkdir -p $(dir $@)
	samtools mpileup ${BAM} -aa -A -d 0 -Q 20 | ivar consensus -p ${PREFIX} -t 0.5 -m 1

# Generates the ivar variant table.
${VARS}: ${BAM} ${REF} ${GFF}
	@mkdir -p $(dir $@)
	samtools mpileup ${BAM} -aa -A -B -d 0 -Q 20 | ivar variants -p ${PREFIX} -t 0.5 -m 1 -r ${REF} -g ${GFF}

# Prints the consensus file location.
cons: ${CONS}
	@echo ""
	@seqkit stats ${CONS}
	@echo

# Remove the consensus.
cons!:
	@rm -rf ${CONS}

# Prints the variant file location.
vars: ${VARS}
	@echo ""
	@echo "# ${VARS}: `cat ${VARS} | wc -l  | tr -d ' '` variants"
	@echo ""

# Remove the variants.
vars!:
	@rm -rf ${VARS}

# Install required software.
install::
	@echo mamba install ivar samtools seqkit
