#
# Generates alignments with salmon
#


# Sequencing read 1.
R1 ?= reads/read1.fq

# Sequencing read 2.
R2 ?= reads/read2.fq

# The reference genome.
CDS ?= refs/transcripts.fa

# Name of the output directory.
PREFIX ?= salmon/sample

# The name of the qunatification file.
QUANT ?= ${PREFIX}/quant.sf

# The indexed reference genome.
IDX = idx/$(notdir ${CDS})

# Alignment mode.
MODE ?= PE

# Number of CPUS
NCPU ?= 2

# Additional hisat2 options.
SMN_FLAGS = -l A

# Targets that are not files.
.PHONY: align align! install usage index

# The first target is always the help.
usage::
	@echo ""
	@echo "# src/salmon.mk: classify reads using salmon "
	@echo ""
	@echo "  make index align"
	@echo ""
	@echo "  in:  MODE=${MODE}"
	@echo "  in:  CDS=${CDS}"
	@echo "  in:  IDX=${IDX}"
	@echo "  in:  R1=${R1}"
ifeq ($(MODE), PE)
	@echo "  in:  R2=${R2}"
endif
	@echo ""
	@echo "  out: PREFIX=${PREFIX}"
	@echo ""
	@echo "  cmd: ${SMN_CMD}"
	@echo ""

# Index the reference.
${IDX}:
	mkdir -p $(dir ${IDX})
	salmon index -p ${NCPU} -t ${CDS} -i ${IDX}

# Different modes depending on single end or paired end reads.
ifeq ($(MODE), PE)
SMN_CMD ?= salmon quant -q ${SMN_FLAGS} -i ${IDX}  -1 ${R1} -2 ${R2} -p ${NCPU} -o ${PREFIX}
else
SMN_CMD ?= salmon quant ${SMN_FLAGS} -i ${IDX}  -r ${R1} -p ${NCPU} -o ${PREFIX}
endif

ifeq ($(MODE), PE)
${QUANT}: ${IDX} ${R1} ${R2}
	mkdir -p ${PREFIX}
	${SMN_CMD}
else
${QUANT}: ${IDX} ${R1}
	mkdir -p ${PREFIX}
	${SMN_CMD}
endif

# Generate the index.
index: ${IDX}
	@echo "# Index: ${IDX}"

# Remove the index.
index!: ${IDX}
	rm -rf ${IDX}

# Target to trigger the alignment.
align: ${QUANT}
	@echo ""
	@echo "# cat ${QUANT} | head"
	@echo ""
	@cat ${QUANT} | head
	@echo ""
	@echo "# QUANT=${QUANT}"
	@echo ""

# Remove the BAM file.
align!:
	@rm -rf ${QUANT}

# Install required software.
install::
	@echo mamba install salmon

