#
# Annotating SNP effects with SNPeff.
#

# Genome accession label
LABEL ?= GENOME

# The GenBank annotation file.
GBK ?= ref/genbank.gb

# The SNPeff database.
SNPEFF ?= data/${LABEL}/snpEffectPredictor.bin

# Variant calls.
VCF ?= vcf/variants.vcf.gz

# Annotated variants.
ANN ?= $(basename $(basename ${VCF})).ann.vcf.gz

# A statistics file on the reference genome.
REF_STATS ?= ${REF}.stats.txt

# Project number (Zaire ebolavirus sample sequencing from the 2014 outbreak in Sierra Leone, West Africa.)
PRJN ?= PRJNA257197

# Project number runinfo.
PRJN_CSV ?= ${PRJN}_runinfo.csv

# Project number SRR numbers.
PRJN_IDS ?= ${PRJN}_srr.txt

# Targets that are not files.
.PHONY: genome runinfo help

SNPEFF_CMD = snpEff -v ${LABEL} ${VCF} | bcftools view -O z > ${ANN}

# General usage information.
usage::
	@echo ""
	@echo "# snpeff.mk: annotate variants calls with SNPeff."
	@echo ""
	@echo "  make annotate"
	@echo ""
	@echo "  in:  LABEL=${LABEL}"
	@echo "  in:  GBK=${GBK}"
	@echo "  in:  VCF=${VCF}"
	@echo ""
	@echo "  out: ANN=${ANN}"
	@echo ""
	@echo "  cmd: ${SNPEFF_CMD}"
	@echo ""

# Building a custom snpEff database.
${SNPEFF}: ${GBK}
	# Snpeff needs the files in specific folders.
	mkdir -p data/${LABEL}

	# Copy the genbank to its location.
	cp -f ${GBK} data/${LABEL}/genes.gbk

	# Append entry to current genome to the config.
	echo "${LABEL}.genome : ${LABEL}" >> snpEff.config

	# Build the snpEff database.
	snpEff build -v ${LABEL}

# Create the annotated VCF file.
${ANN}: ${SNPEFF}
	${SNPEFF_CMD}
	bcftools index ${ANN}

annotate: ${ANN}
	@echo ""
	@echo "# ANN=${ANN} (`bcftools view ${ANN} |  grep -v '^#' | wc -l | tr -d ' '` variants)"
	@echo ""

annotate!:
	rm -f ${ANN}

install::
	@echo mamba install snpeff
