#
# Runs test on all the modules
#

# SRR number to test with
SRR ?= SRR1553591

R1 = reads/SRR1553591_1.fq

# How many reads to use
N ?= 1000

# Check that required executables exist.
EXE = bio bwa samtools bcftools fastp freebayes
K := $(foreach exec,$(EXE),\
        $(if $(shell which $(exec)),ok,$(error "Program: $(exec) not found.")))

.PHONY: all clean run

usage:
	@echo ""
	@echo "# src/test.mk: tests all modules"
	@echo ""
	@echo "   make all"
	@echo ""
	@echo "   make clean"
	@echo ""

# Clean the test directory
clean:
	rm -rf bam/aligned.bam idx/genome.fa*

MAKE = make --no-print-directory

UCSC_URL = https://hgdownload.soe.ucsc.edu/goldenPath/hg38/bigZips/genes/hg38.ensGene.gtf.gz


# Run all the tests.
all:

	${MAKE} -f src/bowtie2.mk index! index

	${MAKE} -f src/bowtie2.mk align

	${MAKE} -f src/minimap2.mk index! index

	${MAKE} -f src/minimap2.mk align

	${MAKE} -f src/hisat2.mk index! index

	${MAKE} -f src/hisat2.mk align

	${MAKE} -f src/bwa.mk index! index

	${MAKE} -f src/bwa.mk align

	${MAKE} -f src/bcftools.mk vcf! vcf

	${MAKE} -f src/freebayes.mk vcf! vcf

	${MAKE} -f src/filter.mk FLT="-e 'QUAL<300'" filter! filter

	${MAKE}  -f src/ncbi.mk genome

	${MAKE}  -f src/sra.mk fastq

	${MAKE}  -f src/sra.mk -f src/ncbi.mk -f src/bwa.mk -f src/bcftools.mk -f src/filter.mk N=${N} SRR=${SRR} align! filter

	${MAKE} -f src/sra.mk -f src/ncbi.mk -f src/bwa.mk -f src/freebayes.mk SAM_FLAGS='-F 4' SRR=${SRR} vcf! vcf

	${MAKE} -f src/sra.mk -f src/ncbi.mk -f src/bwa.mk MODE=SE SRR=${SRR} align! align

	${MAKE} -f src/salmon.mk quant

	@echo ""
	@echo "# Found $(shell find . | wc -l | tr -d ' ') files in $(shell pwd)"
	@echo ""
