#
# Generates SNP calls with varscan
#

# Input BAM file.
BAM ?= bam/alignment.bam

# Reference genome.
REF ?= ref/genome.fa

# Additional bcf flags options
BCF_FLAGS = --ploidy 2

# VCF exclude condition.
EXC ?= DP<5

# Name of the VCF with all variants.
OUT ?= vcf/varscan.txt

# Targets that are not files.
.PHONY: snp snp! install help

# The first target is always the help.
usage::
	@echo ""
	@echo "# src/varscan.mk # calls variants using varscan"
	@echo ""
	@echo "  make snp"
	@echo "  make indel"
	@echo ""
	@echo "  in:  REF=${REF}"
	@echo "  in:  BAM=${BAM}"
	@echo "  out: OUT=${OUT}"
	@echo ""

${OUT}: ${BAM} ${REF}
	@mkdir -p $(dir $@)
	samtools mpileup -f ${REF} ${BAM} | varscan mpileup2snp > $@

snp: ${OUT}
	@echo ""
	@echo "# OUT=${OUT} (`cat ${OUT} | wc -l | tr -d ' '` variants)"
	@echo ""

snp!:
	@rm -rf ${OUT}


# Exploring consensus calling.
cns:
	samtools mpileup -f ${REF} ${BAM} | varscan mpileup2cns > vcf/consensus.txt

install::
	@echo mamba install bcftools
